FlutterDisplayAwakeWeb class
A web implementation of the FlutterDisplayAwakePlatform of the FlutterDisplayAwake plugin.
- Inheritance
-
- Object
- PlatformInterface
- FlutterDisplayAwakePlatform
- FlutterDisplayAwakeWeb
Constructors
- FlutterDisplayAwakeWeb()
- Constructs a FlutterDisplayAwakeWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isKeptOn(
) → Future< bool> -
override
-
keepScreenOff(
) → Future< void> -
override
-
keepScreenOn(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void